@@ -20,7 +20,7 @@ __author__ = "Niklas Fiekas"
 
 __email__ = "niklas.fiekas@tu-clausthal.de"
 
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
 import collections
 import random
@@ -859,8 +859,8 @@ class Bitboard(object):
         self.ep_square = 0
         self.castling_rights = CASTLING
         self.turn = WHITE
-        self.ply = 1
-        self.half_moves = 0
+        self.fullmove_number = 1
+        self.halfmove_clock = 0
 
         for i in range(64):
             if BB_SQUARES[i] & self.occupied:
@@ -868,12 +868,52 @@ class Bitboard(object):
                 self.occupied_r45 |= BB_SQUARES_R45[i]
                 self.occupied_l45 |= BB_SQUARES_L45[i]
 
-        self.half_move_stack = collections.deque()
+        self.halfmove_clock_stack = collections.deque()
         self.captured_piece_stack = collections.deque()
         self.castling_right_stack = collections.deque()
         self.ep_square_stack = collections.deque()
         self.move_stack = collections.deque()
 
+    def clear(self):
+        """
+        Clears the board.
+
+        Resets move stacks and move counters. The side to move is white. There
+        are no rooks or kings, so castling is not allowed.
+
+        In order to be in a valid `status()` at least kings need to be put on
+        the board. This is required for move generation and validation to work
+        properly.
+        """
+        self.pawns = BB_VOID
+        self.knights = BB_VOID
+        self.bishops = BB_VOID
+        self.rooks = BB_VOID
+        self.queens = BB_VOID
+        self.kings = BB_VOID
+
+        self.occupied_co = [ BB_VOID, BB_VOID ]
+        self.occupied = BB_VOID
+
+        self.occupied_l90 = BB_VOID
+        self.occupied_r45 = BB_VOID
+        self.occupied_l45 = BB_VOID
+
+        self.king_squares = [ E1, E8 ]
+        self.pieces = [ NONE for i in range(64) ]
+
+        self.halfmove_clock_stack = collections.deque()
+        self.captured_piece_stack = collections.deque()
+        self.castling_right_stack = collections.deque()
+        self.ep_square_stack = collections.deque()
+        self.move_stack = collections.deque()
+
+        self.ep_square = 0
+        self.castling_rights = CASTLING_NONE
+        self.turn = WHITE
+        self.fullmove_number = 1
+        self.halfmove_clock = 0
+
     def piece_at(self, square):
         """Gets the piece at the given square."""
         mask = BB_SQUARES[square]
@@ -1499,13 +1539,13 @@ class Bitboard(object):
         >>> move in board.pseudo_legal_moves
         True
         """
-        # Increment ply.
+        # Increment fullmove number.
         if self.turn == BLACK:
-            self.ply += 1
+            self.fullmove_number += 1
 
         # Remember game state.
         captured_piece = self.piece_type_at(move.to_square) if move else NONE
-        self.half_move_stack.append(self.half_moves)
+        self.halfmove_clock_stack.append(self.halfmove_clock)
         self.castling_right_stack.append(self.castling_rights)
         self.captured_piece_stack.append(captured_piece)
         self.ep_square_stack.append(self.ep_square)
@@ -1515,15 +1555,15 @@ class Bitboard(object):
         if not move:
             self.turn ^= 1
             self.ep_square = 0
-            self.half_moves += 1
+            self.halfmove_clock += 1
             return
 
         # Update half move counter.
         piece_type = self.piece_type_at(move.from_square)
         if piece_type == PAWN or captured_piece:
-            self.half_moves = 0
+            self.halfmove_clock = 0
         else:
-            self.half_moves += 1
+            self.halfmove_clock += 1
 
         # Promotion.
         if move.promotion:
@@ -1592,12 +1632,12 @@ class Bitboard(object):
         """
         move = self.move_stack.pop()
 
-        # Decrement ply.
+        # Decrement fullmove number.
         if self.turn == WHITE:
-            self.ply -= 1
+            self.fullmove_number -= 1
 
         # Restore state.
-        self.half_moves = self.half_move_stack.pop()
+        self.halfmove_clock = self.halfmove_clock_stack.pop()
         self.castling_rights = self.castling_right_stack.pop()
         self.ep_square = self.ep_square_stack.pop()
         captured_piece = self.captured_piece_stack.pop()
@@ -1654,7 +1694,7 @@ class Bitboard(object):
         Parses the given EPD string and uses it to set the position.
 
         If present the `hmvc` and the `fmvn` are used to set the half move
-        clock and the ply. Otherwise `0` and `1` are used.
+        clock and the fullmove number. Otherwise `0` and `1` are used.
 
         Returns a dictionary of parsed operations. Values can be strings,
         integers, floats or move objects.
@@ -1750,7 +1790,7 @@ class Bitboard(object):
 
         `hmvc` and `fmvc` are *not* included by default. You can use:
 
-        >>> board.epd(hmvc=board.half_moves, fmvc=board.ply)
+        >>> board.epd(hmvc=board.halfmove_clock, fmvc=board.fullmove_number)
         'rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - hmvc 0; fmvc 1;'
         """
         epd = []
@@ -1885,32 +1925,15 @@ class Bitboard(object):
 
         # Check that the half move part is valid.
         if int(parts[4]) < 0:
-            raise ValueError("half moves can not be negative: {0}".format(repr(fen)))
+            raise ValueError("halfmove clock can not be negative: {0}".format(repr(fen)))
 
-        # Check that the ply part is valid.
+        # Check that the fullmove number part is valid.
         # 0 is allowed for compability but later replaced with 1.
         if int(parts[5]) < 0:
-            raise ValueError("ply must be positive: {0}".format(repr(fen)))
+            raise ValueError("fullmove number must be positive: {0}".format(repr(fen)))
 
         # Clear board.
-        self.pawns = BB_VOID
-        self.knights = BB_VOID
-        self.bishops = BB_VOID
-        self.rooks = BB_VOID
-        self.queens = BB_VOID
-        self.kings = BB_VOID
-        self.occupied_co = [ BB_VOID, BB_VOID ]
-        self.occupied = BB_VOID
-        self.occupied_l90 = BB_VOID
-        self.occupied_r45 = BB_VOID
-        self.occupied_l45 = BB_VOID
-        self.king_squares = [ E1, E8 ]
-        self.pieces = [ NONE for i in range(64) ]
-        self.half_move_stack = collections.deque()
-        self.captured_piece_stack = collections.deque()
-        self.castling_right_stack = collections.deque()
-        self.ep_square_stack = collections.deque()
-        self.move_stack = collections.deque()
+        self.clear()
 
         # Put pieces on the board.
         square_index = 0
@@ -1945,8 +1968,8 @@ class Bitboard(object):
             self.ep_square = SQUARE_NAMES.index(parts[3])
 
         # Set the mover counters.
-        self.half_moves = int(parts[4])
-        self.ply = int(parts[5]) or 1
+        self.halfmove_clock = int(parts[4])
+        self.fullmove_number = int(parts[5]) or 1
 
     def fen(self):
         """Gets the FEN representation of the position."""
@@ -1957,11 +1980,11 @@ class Bitboard(object):
 
         # Half moves.
         fen.append(" ")
-        fen.append(str(self.half_moves))
+        fen.append(str(self.halfmove_clock))
 
         # Ply.
         fen.append(" ")
-        fen.append(str(self.ply))
+        fen.append(str(self.fullmove_number))
 
         return "".join(fen)
 
@@ -2246,7 +2269,23 @@ class Bitboard(object):
         return "Bitboard('{0}')".format(self.fen())
 
     def __str__(self):
-        return self.fen()
+        builder = []
+
+        for square in SQUARES_180:
+            piece = self.piece_at(square)
+
+            if piece:
+                builder.append(piece.symbol())
+            else:
+                builder.append(".")
+
+            if BB_SQUARES[square] & BB_FILE_H:
+                if square != H1:
+                    builder.append("\n")
+            else:
+                builder.append(" ")
+
+        return "".join(builder)
 
     def __eq__(self, bitboard):
         return not self.__neq__(bitboard)
@@ -2274,9 +2313,9 @@ class Bitboard(object):
             return True
         if self.turn != bitboard.turn:
             return True
-        if self.ply != bitboard.ply:
+        if self.fullmove_number != bitboard.fullmove_number:
             return True
-        if self.half_moves != bitboard.half_moves:
+        if self.halfmove_clock != bitboard.halfmove_clock:
             return True
 
         return False
